@@ -8,15 +8,15 @@
 #' @export
 build_manual <- function(pkg = ".", path = NULL) {
   pkg <- as.package(pkg)
-  path <- path %||% dirname(pkg$path)
+  path <- path %||% path_dir(pkg$path)
   name <- paste0(pkg$package, "_", pkg$version, ".pdf", collapse = " ")
   tryCatch(msg <- callr::rcmd("Rd2pdf", cmdargs = c(
     "--force",
     paste0("--output=", path, "/", name),
     pkg$path
-  ), fail_on_status = TRUE),
+  ), fail_on_status = TRUE, stderr = "2>&1", spinner = FALSE),
   error = function(e) {
-    cat(e$stderr)
+    cat(e$stdout)
     stop("Failed to build manual", call. = FALSE)
   })
 
